package modality;
import java.awt.Dialog;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.SwingUtilities;

public class DocumentModalDialogDemo {
    private static void constructGUI() {
        final JFrame parent = new JFrame("Parent Frame");
        parent.setLayout(new FlowLayout());
        parent.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        JButton button = new JButton("Document modal dialog");
        button.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {

                // modeless dialog, child of parent
		JDialog dialog1 = new JDialog(parent, 
                        "Dialog1 - Modeless Dialog");
                dialog1.setBounds(200, 200, 300, 200);
                dialog1.setVisible(true);

                // document-modal dialog, child of parent 
                JDialog dialog2 = new JDialog(parent, 
                        "Dialog2 - Document-Modal Dialog", 
                        Dialog.ModalityType.DOCUMENT_MODAL);
                dialog2.setBounds(300, 300, 300, 200);

                // modeless dialog, child of dialog2, not affected by
                // the modality of dialog2
                JDialog dialog3 = new JDialog(dialog2, 
                        "Dialog3 - Modeless Dialog");
                dialog3.setBounds(400, 400, 300, 200);
                dialog3.setVisible(true);

                // display dialog2 after dialog3 is shown so that dialog3
                // won't be blocked by dialog2
                dialog2.setVisible(true);
            }
        });
        parent.add(button);
        parent.setBounds(100, 100, 300, 200);
        parent.setVisible(true);
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                constructGUI();
            }
        });
    }
}
